==> hoteldruid-mod-sv_2.2.3-1.tar.gz: sv/modifica_ospiti.php <==
<?php

switch ($messaggio) {

case "Modifica gli ospiti della prenotazione":	$messaggio = "&Auml;ndra bokningsg&auml;ster"; break;
case "Cliente titolare":  			$messaggio = "Bokningsinnehavare"; break;
case "Ospite della prenotazione":  		$messaggio = "Bokningsg&auml;st"; break;
case "nato il":  				$messaggio = "f&ouml;dd"; break;
case "nata il":  				$messaggio = "f&ouml;dd"; break;
case "CAP":  					$messaggio = "postnummer"; break;
case "Telefono":  				$messaggio = "Telefon"; break;
case "2º telefono":  				$messaggio = "Andra telefon"; break;
case "3º telefono":  				$messaggio = "Tredje telefon"; break;
case "Cognome":  				$messaggio = "Efternamn"; break;
case "nome":  					$messaggio = "f&ouml;rnamn"; break;
case "sesso":  					$messaggio = "k&ouml;n"; break;
case "Data di nascita":  			$messaggio = "F&ouml;delsedatum"; break;
case "anno con 4 cifre":  			$messaggio = "&aring;r med fyra siffror"; break;
case "Documento":  				$messaggio = "Dokument"; break;
case "scadenza":  				$messaggio = "upph&ouml;randedatum"; break;
case "Altri ospiti":  				$messaggio = "Andra g&auml;ster"; break;
case "Modifica gli ospiti":  			$messaggio = "&Auml;ndra g&auml;ster"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Gli ospiti della prenotazione":  		$messaggio = "Bokningsg&auml;sterna"; break;
case "sono stati modificati":  			$messaggio = "har &auml;ndrats"; break;
case "nato":  					$messaggio = "f&ouml;dd"; break;
case "nata":  					$messaggio = "f&ouml;dd"; break;
case "il":  					$messaggio = ""; break;
case " a":  					$messaggio = " i"; break;
case "scade":  					$messaggio = "l&ouml;per ut"; break;
case "città di nascita":  			$messaggio = "f&ouml;delsestad"; break;
case "reg./prov. di nascita":  			$messaggio = "f&ouml;delseregion"; break;
case "nazione di nascita":  			$messaggio = "f&ouml;delseland"; break;
case "nazione":  				$messaggio = "land"; break;
case "Nazione":  				$messaggio = "Land"; break;
case "rilasciato da":  				$messaggio = "utf&auml;rdat av"; break;
case "nazione di rilascio":  			$messaggio = "utf&auml;rdandeland"; break;
case "Ospite principale":  			$messaggio = "Huvudg&auml;st"; break;
case "Parentela":  				$messaggio = "Sl&auml;ktskap"; break;
case "parentela":  				$messaggio = "sl&auml;ktskap"; break;
case "Codice fiscale":  			$messaggio = "Skattekod"; break;
case "città":  					$messaggio = "stad"; break;
case "ln.":  					$messaggio = "ln."; break;
case "cittadinanza":  				$messaggio = "nationality"; break;
case "reg./prov.":  				$messaggio = "region"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "Modifica gli ospiti delle prenotazioni":	$messaggio = "Modify guests of reservations"; break;
case "della prenotazione":  			$messaggio = "of reservation"; break;
case "Gli ospiti delle prenotazioni":  		$messaggio = "The guests of reservations"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-sv_3.0.3-1.tar.gz: sv/modifica_ospiti.php <==
<?php

switch ($messaggio) {

case "Modifica gli ospiti della prenotazione":	$messaggio = "&Auml;ndra bokningsg&auml;ster"; break;
case "Cliente titolare":  			$messaggio = "Bokningsinnehavare"; break;
case "Ospite della prenotazione":  		$messaggio = "Bokningsg&auml;st"; break;
case "nato il":  				$messaggio = "f&ouml;dd"; break;
case "nata il":  				$messaggio = "f&ouml;dd"; break;
case "CAP":  					$messaggio = "postnummer"; break;
case "Telefono":  				$messaggio = "Telefon"; break;
case "2º telefono":  				$messaggio = "Andra telefon"; break;
case "3º telefono":  				$messaggio = "Tredje telefon"; break;
case "Cognome":  				$messaggio = "Efternamn"; break;
case "nome":  					$messaggio = "f&ouml;rnamn"; break;
case "sesso":  					$messaggio = "k&ouml;n"; break;
case "Data di nascita":  			$messaggio = "F&ouml;delsedatum"; break;
case "anno con 4 cifre":  			$messaggio = "&aring;r med fyra siffror"; break;
case "Documento":  				$messaggio = "Dokument"; break;
case "scadenza":  				$messaggio = "upph&ouml;randedatum"; break;
case "Altri ospiti":  				$messaggio = "Andra g&auml;ster"; break;
case "Modifica gli ospiti":  			$messaggio = "&Auml;ndra g&auml;ster"; break;
case "Torna indietro":  			$messaggio = "Tillbaka"; break;
case "Gli ospiti della prenotazione":  		$messaggio = "Bokningsg&auml;sterna"; break;
case "sono stati modificati":  			$messaggio = "har &auml;ndrats"; break;
case "nato":  					$messaggio = "f&ouml;dd"; break;
case "nata":  					$messaggio = "f&ouml;dd"; break;
case "il":  					$messaggio = ""; break;
case " a":  					$messaggio = " i"; break;
case "scade":  					$messaggio = "l&ouml;per ut"; break;
case "città di nascita":  			$messaggio = "f&ouml;delsestad"; break;
case "reg./prov. di nascita":  			$messaggio = "f&ouml;delseregion"; break;
case "nazione di nascita":  			$messaggio = "f&ouml;delseland"; break;
case "nazione":  				$messaggio = "land"; break;
case "Nazione":  				$messaggio = "Land"; break;
case "rilasciato da":  				$messaggio = "utf&auml;rdat av"; break;
case "nazione di rilascio":  			$messaggio = "utf&auml;rdandeland"; break;
case "Ospite principale":  			$messaggio = "Huvudg&auml;st"; break;
case "Parentela":  				$messaggio = "Sl&auml;ktskap"; break;
case "parentela":  				$messaggio = "sl&auml;ktskap"; break;
case "Codice fiscale":  			$messaggio = "Skattekod"; break;
case "città":  					$messaggio = "stad"; break;
case "ln.":  					$messaggio = "ln."; break;
case "Modifica Ospiti":  			$messaggio = "Modify Guests"; break;
case "cittadinanza":  				$messaggio = "nationality"; break;
case "reg./prov.":  				$messaggio = "region"; break;
case "Partita iva":  				$messaggio = "VAT number"; break;
case "Modifica gli ospiti delle prenotazioni":	$messaggio = "Modify guests of reservations"; break;
case "della prenotazione":  			$messaggio = "of reservation"; break;
case "Gli ospiti delle prenotazioni":  		$messaggio = "The guests of reservations"; break;
case "email":  					$messaggio = "email"; break;
case "2ª email":  				$messaggio = "2nd email"; break;
case "PEC/codice":  				$messaggio = "certified email"; break;
case "":  		$messaggio = ""; break;
case "":  		$messaggio = ""; break;

} # fine switch ($messaggio)

?>
